/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.mingraviditet.ui.main.journal.extensions


import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.util.extensions.toSingleDigitString
import dk.nsp.mingraviditet.util.extensions.toTextModelOrDefault
import dk.nsp.models.DoubleValueWithUnitEnum
import dk.nsp.models.IntegerValueWithUnitEnum
import dk.nsp.models.NumericValueWithUnit
import dk.nsp.models.RangeValueWithUnit
import dk.nsp.util.TextModel
import dk.nsp.util.toTextModel

fun IntegerValueWithUnitEnum?.toTextModel(): TextModel {
    val value = this?.value.toTextModelOrDefault()
    val unit = this?.unit?.value.toTextModelOrDefault()

    return TextModel.from(R.string.space_between_values, value, unit)
}

fun IntegerValueWithUnitEnum?.toTextModelWithoutUnit(): TextModel {
    return this?.value.toTextModelOrDefault()
}

fun DoubleValueWithUnitEnum?.toTextModel(): TextModel {
    val value = this?.value?.let { TextModel.from(it.toString()) }
        ?: return TextModel.from(R.string.common_missing_data)
    val unit = this.unit?.value.toTextModelOrDefault()

    return TextModel.from(R.string.space_between_values, value, unit)
}

fun DoubleValueWithUnitEnum?.toTextModelWithoutUnit(): TextModel {
    return this?.value?.let { TextModel.from(it.toString()) }
        ?: return TextModel.from(R.string.common_missing_data)
}

fun NumericValueWithUnit?.toTextModel(): TextModel {
    val numberVal = this?.value ?: return TextModel.from(R.string.common_missing_data)

    val valueString = numberVal.toSingleDigitString().toTextModel()
    val unitString = (unit ?: "").toTextModel()
    return TextModel.from(R.string.space_between_values, valueString, unitString)
}

fun RangeValueWithUnit?.toTextModel(): TextModel {
    val rangeVal = this?.value?.let { TextModel.from(it) } ?: return TextModel.from(R.string.common_missing_data)
    val unit = unit.toTextModelOrDefault()

    return TextModel.from(R.string.space_between_values, rangeVal, unit)
}