/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.mingraviditet.ui.main.more.settings

import android.content.Intent
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.viewModels
import com.google.android.material.bottomsheet.BottomSheetDialogFragment
import com.google.android.material.snackbar.Snackbar
import dagger.hilt.android.AndroidEntryPoint
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.RemoveConsentBottomSheetBinding
import dk.nsp.mingraviditet.extensions.disable
import dk.nsp.mingraviditet.ui.useradmission.UserAdmissionActivity
import dk.nsp.mingraviditet.util.UserStateHandler
import dk.nsp.mingraviditet.util.extensions.observeIfNotHandled
import dk.nsp.shared.Failed
import dk.nsp.shared.Success
import javax.inject.Inject

@AndroidEntryPoint
class RemoveConsentBottomSheet : BottomSheetDialogFragment() {
    val binding: RemoveConsentBottomSheetBinding by lazy {
        RemoveConsentBottomSheetBinding.inflate(LayoutInflater.from(context), null, false)
    }

    private val consentViewModel by viewModels<ConsentViewModel>()

    @Inject lateinit var userStateHandler: UserStateHandler

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        setStyle(STYLE_NORMAL, R.style.TransparentDialog)
    }


    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        binding.closeButton.setOnClickListener { dismiss() }
        binding.removeConsent.setOnClickListener {
            binding.removeConsent.disable()
            consentViewModel.removeConsent()
        }
    }


    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        consentViewModel.onConsentRemoved.observeIfNotHandled(viewLifecycleOwner) {
            when (it) {
                is Failed -> Snackbar.make(
                    binding.root,
                    it.error.message ?: "Kunne ikke fjerne samtykke",
                    Snackbar.LENGTH_LONG
                )
                    .show()
                is Success -> {
                    startActivity(Intent(binding.root.context, UserAdmissionActivity::class.java))
                    activity?.finishAffinity()
                }
            }
        }
        return binding.root
    }

}