/*
 * The MIT License
 *   
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *   
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *   
 *   
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *   
 *   
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *   
 *   
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.mingraviditet.util.extensions

import dk.nsp.testassertions.assertEquals
import dk.nsp.testassertions.assertNull
import org.junit.jupiter.api.Test
import java.time.LocalDateTime

class LocalDateTimeExtensionsTest {

    private val nullDate: LocalDateTime? = null
    private val src = LocalDateTime.of(2021, 4, 16, 12, 59, 1, 99)

    @Test
    fun toPrettyString() {
        src.toPrettyString().assertEquals("16. April 2021 kl. 12:59")
    }

    @Test
    fun toMediumFormat() {
        src.toMediumFormat().assertEquals("16.04.2021")

        nullDate.toMediumFormat().assertNull()
    }

    @Test
    fun toLongFormat() {
        src.toLongFormat().assertEquals("Friday, 16 April")

        nullDate.toLongFormat().assertEquals("")
    }

    @Test
    fun toFullDateFormat() {
        src.toFullDateFormat().assertEquals("Friday, 16 April 2021")

        nullDate.toFullDateFormat().assertEquals("")
    }

    @Test
    fun toTimeFormat() {
        src.toTimeFormat().assertEquals("12:59")
    }

    @Test
    fun toLongMonthFormat() {
        src.toLongMonthFormat().assertEquals("April")
    }

    @Test
    fun withTimeAtStartOfDay() {
        val startOfDay = src.withTimeAtStartOfDay()
        startOfDay.hour.assertEquals(0)
        startOfDay.minute.assertEquals(0)
    }
}