/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.mingraviditet.util.extensions

import dk.nsp.models.ObservationType
import dk.nsp.testassertions.assertFalse
import dk.nsp.testassertions.assertTrue
import org.junit.jupiter.api.Test

class ObservationTypeExtensionsTest {

    @Test
    fun observationTypeIsFetusObservation() {
        ObservationType.FetusActivity.isFetusObservation().assertTrue()
        ObservationType.FetusPresentation.isFetusObservation().assertTrue()
        ObservationType.FetusWeightEstimate.isFetusObservation().assertTrue()

        ObservationType.Weight.isFetusObservation().assertFalse()
        ObservationType.BloodPressure.isFetusObservation().assertFalse()
        ObservationType.Urine.isFetusObservation().assertFalse()
        ObservationType.Edema.isFetusObservation().assertFalse()
        ObservationType.PubisMeasurements.isFetusObservation().assertFalse()
        ObservationType.FetusWeightEstimateUltrasound.isFetusObservation().assertFalse()
        ObservationType.FetusPresentationUltrasound.isFetusObservation().assertFalse()
        ObservationType.Cervix.isFetusObservation().assertFalse()
        ObservationType.Dvp.isFetusObservation().assertFalse()
        ObservationType.GestationAge.isFetusObservation().assertFalse()
        ObservationType.GestationAgeUltrasound.isFetusObservation().assertFalse()
        ObservationType.WeightDeviation.isFetusObservation().assertFalse()
        ObservationType.AmnioticFluid.isFetusObservation().assertFalse()
        ObservationType.Flow.isFetusObservation().assertFalse()
    }
}